xenon
=====

.. image:: http://img.shields.io/travis/rubik/xenon/master.svg?style=flat
    :alt: Travis-CI badge
    :target: https://travis-ci.org/rubik/xenon

.. image:: http://img.shields.io/coveralls/rubik/xenon/master.svg?style=flat
    :alt: Coveralls badge
    :target: https://coveralls.io/r/rubik/xenon?branch=master

.. image:: https://pypip.in/v/xenon/badge.png?style=flat
    :alt: PyPI latest version badge
    :target: https://crate.io/packages/xenon


.. image:: https://pypip.in/d/xenon/badge.png?style=flat
    :alt: PyPI downloads badge
    :target: https://pypi.python.org/pypi/xenon/

.. image:: https://pypip.in/format/xenon/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/xenon/
    :alt: Download format

.. image:: https://pypip.in/license/xenon/badge.png?style=flat
    :alt: Xenon license
    :target: https://pypi.python.org/pypi/xenon/

Monitoring tool based on [radon](https://github.com/rubik/radon/).
